@@ -51,7 +51,7 @@
 
 using Akonadi::ProcessControl;
 
-#if defined(Q_WS_MAEMO_5) || defined(_WIN32_WCE)
+#if defined(Q_WS_MAEMO_5)
 static bool enableAgentServerDefault = true;
 #else
 static bool enableAgentServerDefault = false;
@@ -84,7 +84,7 @@ AgentManager::AgentManager( QObject *parent )
   }
 
   mStorageController = new Akonadi::ProcessControl;
-  mStorageController->setShutdownTimeout( 10 * 1000 ); // the server needs more time for shutdown if we are using an internal mysqld
+  mStorageController->setShutdownTimeout( 15 * 1000 ); // the server needs more time for shutdown if we are using an internal mysqld
   connect( mStorageController, SIGNAL(unableToStart()), SLOT(serverFailure()) );
   mStorageController->start( QLatin1String( "akonadiserver" ), serviceArgs, Akonadi::ProcessControl::RestartOnCrash );
 
@@ -452,7 +452,7 @@ void AgentManager::agentInstanceSynchronizeCollectionTree( const QString &identi
     return;
   }
 
-  mAgentInstances.value( identifier  )->resourceInterface()->synchronizeCollectionTree();
+  mAgentInstances.value( identifier )->resourceInterface()->synchronizeCollectionTree();
 }
 
 void AgentManager::agentInstanceSynchronizeCollection( const QString &identifier, qint64 collection )
@@ -629,14 +629,15 @@ void AgentManager::save()
   file.sync();
 }
 
-void AgentManager::serviceOwnerChanged( const QString &name, const QString&, const QString &newOwner )
+void AgentManager::serviceOwnerChanged( const QString &name, const QString &oldOwner, const QString &newOwner )
 {
+  Q_UNUSED( oldOwner );
   // This is called by the D-Bus server when a service comes up, goes down or changes ownership for some reason
   // and this is where we "hook up" our different Agent interfaces.
 
   //akDebug() << "Service " << name << " owner changed from " << oldOwner << " to " << newOwner;
 
-  if ( (name == AkDBus::serviceName( AkDBus::Server ) || name == AkDBus::serviceName( AkDBus::AgentServer )) && !newOwner.isEmpty() ) {
+  if ( ( name == AkDBus::serviceName( AkDBus::Server ) || name == AkDBus::serviceName( AkDBus::AgentServer ) ) && !newOwner.isEmpty() ) {
     if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName( AkDBus::Server ) )
       && ( !mAgentServer || QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName( AkDBus::AgentServer ) ) ) ) {
       // server is operational, start agents
@@ -763,7 +764,7 @@ bool AgentManager::checkResourceInterface( const QString &identifier, const QStr
     return false;
   }
 
-  if ( !mAgents[ mAgentInstances[identifier]->agentType() ].capabilities.contains( QLatin1String( "Resource" ) ) ) {
+  if ( !mAgents[mAgentInstances[identifier]->agentType()].capabilities.contains( QLatin1String( "Resource" ) ) ) {
     return false;
   }
 
@@ -810,7 +811,7 @@ void AgentManager::ensureAutoStart( const AgentType &info )
                                                       QLatin1String( "/AgentServer" ), QDBusConnection::sessionBus(), this );
 
   if ( mAgentInstances.contains( info.identifier ) ||
-       (agentServer.isValid() && agentServer.started( info.identifier )) ) {
+       ( agentServer.isValid() && agentServer.started( info.identifier ) ) ) {
     return; // already running
   }
 
