@@ -30,7 +30,7 @@ class QProcess;
 namespace Akonadi {
 namespace Server {
 
-class Connection;
+class ConnectionThread;
 class CacheCleaner;
 class SearchManagerThread;
 class ItemRetrievalThread;
@@ -43,40 +43,55 @@ class AkonadiServer : public QLocalServer
     Q_OBJECT
 
   public:
+    ~AkonadiServer();
     static AkonadiServer *instance();
 
-    AkonadiServer( QObject *parent = 0 );
-    ~AkonadiServer();
+    /**
+     * Can return a nullptr
+     */
+    CacheCleaner *cacheCleaner();
+
+    /**
+     * Can return a nullptr
+     */
+    IntervalCheck *intervalChecker();
+
 
   public Q_SLOTS:
     /**
      * Triggers a clean server shutdown.
      */
-    void quit();
+    virtual bool quit();
+
+    virtual bool init();
 
   private Q_SLOTS:
-    void init();
     void doQuit();
     void serviceOwnerChanged ( const QString &name, const QString &oldOwner, const QString &newOwner );
 
   protected:
     /** reimpl */
-    void incomingConnection( quintptr socketDescriptor );
+    virtual void incomingConnection( quintptr socketDescriptor );
 
   private:
     void startDatabaseProcess();
     void createDatabase();
     void stopDatabaseProcess();
 
+  protected:
+    AkonadiServer( QObject *parent = 0 );
+
     CacheCleaner *mCacheCleaner;
     IntervalCheck *mIntervalChecker;
     StorageJanitorThread *mStorageJanitor;
     ItemRetrievalThread *mItemRetrievalThread;
     SearchTaskManagerThread *mAgentSearchManagerThread;
     QProcess *mDatabaseProcess;
-    QVector< QPointer<Connection> > mConnections;
+    QVector< QPointer<ConnectionThread> > mConnections;
     SearchManagerThread *mSearchManager;
     bool mAlreadyShutdown;
+
+    static AkonadiServer *s_instance;
 };
 
 } // namespace Server
