@@ -23,6 +23,7 @@
 #include <entities.h>
 
 #include <QtCore/QDateTime>
+#include <QtCore/QVector>
 
 class QTemporaryFile;
 namespace Akonadi {
@@ -42,19 +43,46 @@ class AkAppend : public Handler
 public:
     AkAppend();
 
-    ~AkAppend();
+    virtual ~AkAppend();
 
-    bool parseStream();
+    virtual bool parseStream();
 
 protected:
+    class ChangedAttributes
+    {
+    public:
+        ChangedAttributes()
+            : incremental(false)
+        {
+        }
+
+        bool incremental;
+        QVector<QByteArray> added;
+        QVector<QByteArray> removed;
+    };
+
     bool buildPimItem( PimItem &item,
-                       const QByteArray &mailbox, qint64 size,
-                       const QList<QByteArray> &flags,
-                       const QDateTime &dateTime,
-                       QList<QByteArray> &itemFlags );
+                       Collection &parentCollection,
+                       ChangedAttributes &flags,
+                       ChangedAttributes &tagsRID,
+                       ChangedAttributes &tagsGID );
+
+
+    bool insertItem( PimItem &item,
+                     const Collection &parentCollection,
+                     const QVector<QByteArray> &itemFlags,
+                     const QVector<QByteArray> &itemTagsRID,
+                     const QVector<QByteArray> &itemTagsGID );
 
     bool readParts( PimItem &item );
 
+    virtual bool notify( const PimItem &item, const Collection &collection );
+    virtual bool sendResponse( const QByteArray &response, const PimItem &item );
+
+
+private:
+    QByteArray parseFlag( const QByteArray &flag ) const;
+
 };
 
 } // namespace Server
