@@ -92,7 +92,7 @@ bool Append::commit()
     QString remote_id;
     QString remote_revision;
     QString gid;
-    QList<QByteArray> flags;
+    QVector<QByteArray> flags;
     Q_FOREACH ( const QByteArray &flag, m_flags ) {
       if ( flag.startsWith( "\\MimeType" ) ) {
         int pos1 = flag.indexOf( '[' );
@@ -164,7 +164,7 @@ bool Append::commit()
     // set message flags
     const Flag::List flagList = HandlerHelper::resolveFlags( flags );
     bool flagsChanged = false;
-    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) ) {
+    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, &flagsChanged, false, col ) ) {
       return failureResponse( "Unable to append item flags." );
     }
 
