@@ -34,6 +34,9 @@
 #include <search/searchmanager.h>
 #include <akdebug.h>
 #include <cachecleaner.h>
+#include <collectionreferencemanager.h>
+#include <akonadi.h>
+#include <intervalcheck.h>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
@@ -43,6 +46,18 @@ Modify::Modify( Scope::SelectionScope scope )
 {
 }
 
+static Tristate getTristateValue( const QByteArray &line,  int &pos )
+{
+  QByteArray tmp;
+  pos = ImapParser::parseString( line, tmp, pos );
+  if ( tmp == "TRUE" ){
+    return Tristate::True;
+  } else if ( tmp == "FALSE" ){
+    return Tristate::False;
+  }
+  return Tristate::Undefined;
+}
+
 bool Modify::parseStream()
 {
   m_scope.parseScope( m_streamParser );
@@ -217,6 +232,43 @@ bool Modify::parseStream()
 
         changes.append( AKONADI_PARAM_PERSISTENTSEARCH );
       }
+    } else if ( type == AKONADI_PARAM_ENABLED ) {
+      //Not actually a tristate
+      const bool enabled = ( getTristateValue( line, pos ) == Tristate::True );
+      if ( enabled != collection.enabled() ) {
+        collection.setEnabled( enabled );
+        changes.append( AKONADI_PARAM_ENABLED );
+      }
+    } else if ( type == AKONADI_PARAM_SYNC ) {
+      const Tristate tristate = getTristateValue( line, pos );
+      if ( tristate != collection.syncPref() ) {
+        collection.setSyncPref ( tristate );
+        changes.append( AKONADI_PARAM_SYNC );
+      }
+    } else if ( type == AKONADI_PARAM_DISPLAY ) {
+      const Tristate tristate = getTristateValue( line, pos );
+      if ( tristate != collection.displayPref() ) {
+        collection.setDisplayPref ( tristate );
+        changes.append( AKONADI_PARAM_DISPLAY );
+      }
+    } else if ( type == AKONADI_PARAM_INDEX ) {
+      const Tristate tristate = getTristateValue( line, pos );
+      if ( tristate != collection.indexPref() ) {
+        collection.setIndexPref ( tristate );
+        changes.append( AKONADI_PARAM_INDEX );
+      }
+    } else if ( type == AKONADI_PARAM_REFERENCED ) {
+      //Not actually a tristate
+      const bool reference = ( getTristateValue( line, pos ) == Tristate::True );
+      connection()->collectionReferenceManager()->referenceCollection(connection()->sessionId(), collection, reference);
+      const bool referenced = connection()->collectionReferenceManager()->isReferenced(collection.id());
+      if ( referenced != collection.referenced() ) {
+        collection.setReferenced( referenced );
+        if ( AkonadiServer::instance()->intervalChecker() && referenced ) {
+          AkonadiServer::instance()->intervalChecker()->requestCollectionSync( collection );
+        }
+        changes.append( AKONADI_PARAM_REFERENCED );
+      }
     } else if ( type.isEmpty() ) {
       break; // input end
     } else {
@@ -269,6 +321,14 @@ bool Modify::parseStream()
       return failureResponse( "Unable to update collection" );
     }
     db->notificationCollector()->collectionChanged( collection, changes );
+    //For backwards compatibility. Must be after the changed notification (otherwise the compression removes it).
+    if ( changes.contains( AKONADI_PARAM_ENABLED ) ) {
+      if ( collection.enabled() ) {
+        db->notificationCollector()->collectionSubscribed( collection );
+      } else {
+        db->notificationCollector()->collectionUnsubscribed( collection );
+      }
+    }
     if ( !transaction.commit() ) {
       return failureResponse( "Unable to commit transaction" );
     }
