@@ -31,6 +31,8 @@
 namespace Akonadi {
 namespace Server {
 
+class CommandContext;
+
 class ImapStreamParser;
 
 /**
@@ -85,13 +87,15 @@ class HandlerHelper
     */
     static QByteArray cachePolicyToByteArray( const Collection &col );
 
+    static QByteArray tristateToByteArray( const Tristate &tristate );
+
     /**
       Returns the protocol representation of the given collection.
       Make sure DataStore::activeCachePolicy() has been called before to include
       the effective cache policy
     */
     static QByteArray collectionToByteArray( const Collection &col, bool hidden = false, bool includeStatistics = false,
-                                             int ancestorDepth = 0, const QStack<Collection> &ancestors = QStack<Collection>() );
+                                             int ancestorDepth = 0, const QStack<Collection> &ancestors = QStack<Collection>(), bool isReferenced = false );
 
     /**
       Returns the protocol representation of a collection ancestor chain.
@@ -107,13 +111,17 @@ class HandlerHelper
       Converts a bytearray list of flag names into flag records.
       @throws HandlerException on errors during datbase operations
     */
-    static Flag::List resolveFlags( const QList<QByteArray> &flagNames );
+    static Flag::List resolveFlags( const QVector<QByteArray> &flagNames );
 
     /**
       Converts a imap set of tags into tag records.
       @throws HandlerException on errors during datbase operations
     */
     static Tag::List resolveTags( const ImapSet &tags );
+
+    static Tag::List resolveTagsByGID( const QVector<QByteArray> &tagsGIDs );
+
+    static Tag::List resolveTagsByRID( const QVector<QByteArray> &tagsRIDs, CommandContext *context );
 };
 
 } // namespace Server
