@@ -59,6 +59,15 @@ class ImapStreamParser
      */
     ~ImapStreamParser();
 
+    /**
+     * Sets how long the parser should wait for socket to provide more data before
+     * aborting with error.
+     *
+     * Default value is 30 seconds. This method is used mainly to speed up
+     * unittests.
+     */
+    void setWaitTimeout(int msecs);
+
     /**
      * Get a string from the message. If the upcoming data is not a quoted string, unquoted string or a literal,
      * the behavior is undefined. Use @ref hasString to be sure a string comes. This call might block.
@@ -117,7 +126,7 @@ class ImapStreamParser
      * This call might block.
      * @return true if a literal follows
      */
-    bool hasLiteral();
+    bool hasLiteral( bool requestData = true);
 
     /**
      * Read the next literal sequence. This might or might not be the full data. Example code to read a literal would be:
@@ -243,6 +252,12 @@ class ImapStreamParser
      */
     void setTracerIdentifier( const QString &id );
 
+    /**
+     * Inform the client to send more literal data.
+     * @param size size of the requested literal in bytes
+     */
+    void sendContinuationResponse( qint64 size );
+
   private:
     QByteArray parseQuotedString();
 
@@ -254,12 +269,6 @@ class ImapStreamParser
      */
     bool waitForMoreData( bool wait );
 
-    /**
-     * Inform the client to send more literal data.
-     * @param size size of the requested literal in bytes
-     */
-    void sendContinuationResponse( qint64 size );
-
     QIODevice *m_socket;
     QByteArray m_data;
     QByteArray m_tag;
@@ -267,6 +276,8 @@ class ImapStreamParser
     int m_position;
     qint64 m_literalSize;
     bool m_peeking;
+    int m_timeout;
+
 };
 
 } // namespace Server
