@@ -26,6 +26,7 @@
 #include "agentsearchengine.h"
 #include "nepomuksearchengine.h"
 #include "notificationmanager.h"
+#include "dbusconnectionpool.h"
 #include "searchrequest.h"
 #include "searchtaskmanager.h"
 #include "storage/datastore.h"
@@ -66,12 +67,13 @@ SearchManagerThread::~SearchManagerThread()
 
 void SearchManagerThread::run()
 {
-  SearchManager *manager = new SearchManager( mSearchEngines );
+  SearchManager *manager = new SearchManager();
+  manager->init( mSearchEngines );
   exec();
   delete manager;
 }
 
-SearchManager::SearchManager( const QStringList &searchEngines, QObject *parent )
+SearchManager::SearchManager( QObject *parent )
   : QObject( parent )
 {
   qRegisterMetaType< QSet<qint64> >();
@@ -81,6 +83,11 @@ SearchManager::SearchManager( const QStringList &searchEngines, QObject *parent
   Q_ASSERT( sInstance == 0 );
   sInstance = this;
 
+  DataStore::self();
+}
+
+void SearchManager::init(const QStringList& searchEngines)
+{
   mEngines.reserve( searchEngines.size() );
   Q_FOREACH ( const QString &engineName, searchEngines ) {
     if ( engineName == QLatin1String( "Nepomuk" ) ) {
@@ -97,12 +104,12 @@ SearchManager::SearchManager( const QStringList &searchEngines, QObject *parent
   loadSearchPlugins();
 
   new SearchManagerAdaptor( this );
-
   QDBusConnection::sessionBus().registerObject(
       QLatin1String( "/SearchManager" ),
       this,
       QDBusConnection::ExportAdaptors );
 
+
   // The timer will tick 15 seconds after last change notification. If a new notification
   // is delivered in the meantime, the timer is reset
   mSearchUpdateTimer = new QTimer( this );
@@ -110,8 +117,6 @@ SearchManager::SearchManager( const QStringList &searchEngines, QObject *parent
   mSearchUpdateTimer->setSingleShot( true );
   connect( mSearchUpdateTimer, SIGNAL(timeout()),
            this, SLOT(searchUpdateTimeout()) );
-
-  DataStore::self();
 }
 
 SearchManager::~SearchManager()
