@@ -24,6 +24,9 @@
 
 class QProcess;
 
+namespace Akonadi {
+namespace Server {
+
 class DbConfigMysql : public DbConfig
 {
   public:
@@ -86,4 +89,7 @@ class DbConfigMysql : public DbConfig
     QProcess *mDatabaseProcess;
 };
 
+} // namespace Server
+} // namespace Akonadi
+
 #endif
