@@ -23,6 +23,7 @@
 #include "handler/scope.h"
 
 namespace Akonadi {
+namespace Server {
 
 class QueryBuilder;
 class Scope;
@@ -36,8 +37,10 @@ namespace QueryHelper
     Add conditions to @p qb for the given uid set @p set applied to @p column.
   */
   void setToQuery( const ImapSet &set, const QString &column, QueryBuilder &qb );
-}
 
-}
+} // namespace QueryHelper
+
+} // namespace Server
+} // namespace Akonadi
 
 #endif
