@@ -24,7 +24,7 @@
 #include "handler/scope.cpp"
 #include "imapstreamparser.h"
 
-using namespace Akonadi;
+using namespace Akonadi::Server;
 
 Q_DECLARE_METATYPE( Scope::SelectionScope )
 
@@ -112,8 +112,8 @@ class ScopeTest : public QObject
 
       QTest::newRow( "null" ) << QByteArray() << QStringList() << false;
       QTest::newRow( "empty" ) << QByteArray( "()" ) << QStringList() << true;
-      QTest::newRow( "root" ) << QByteArray( "((0 \"\"))" ) << (QStringList() << QLatin1String("")) << true;
-      QTest::newRow( "chain") << QByteArray( "((1 \"r1\") (2 \"r2\"))" ) << (QStringList() << QLatin1String("r1") << QLatin1String("r2")) << true;
+      QTest::newRow( "root" ) << QByteArray( "((0 \"\"))" ) << ( QStringList() << QLatin1String( "" ) ) << true;
+      QTest::newRow( "chain" ) << QByteArray( "((1 \"r1\") (2 \"r2\"))" ) << ( QStringList() << QLatin1String( "r1" ) << QLatin1String( "r2" ) ) << true;
       QTest::newRow( "invalid 1" ) << QByteArray( "(foo)" ) << QStringList() << false;
       QTest::newRow( "invalid 2" ) << QByteArray( "foo" ) << QStringList() << false;
       QTest::newRow( "invalid 3" ) << QByteArray( "((foo)" ) << QStringList() << false;
@@ -134,7 +134,7 @@ class ScopeTest : public QObject
       bool didThrow = false;
       try {
         scope.parseScope( &parser );
-      } catch ( const Akonadi::Exception &e ) {
+      } catch ( const Akonadi::Server::Exception &e ) {
         didThrow = true;
         if ( success ) {
           qDebug() << e.type() << e.what();
